@@ -71,14 +71,46 @@ def speak(text: str, language='en-us', voice='f1', pitch=50,
         speech, defaults to None. When present, audio is not played.
     :type fp: path-like, optional
     """
+    if language not in list(LANGUAGES):
+        print("ERROR: 'language' must be a valid eSpeak-NG language key.")
+        print("See pySpeakNG.LANGUAGES for valid keys and descriptions.")
+
+    if voice not in VOICES:
+        print("ERROR: 'voice' must be a valid eSpeak-NG voice name.")
+        print("See pySpeakNG.VOICES for options.")
+
+    if pitch < 0:
+        pitch = 0
+    elif pitch > 99:
+        pitch = 99
+
+    if speed < 25:
+        speed = 25
+    elif speed > 250:
+        speed = 250
+
+    if gap < 0:
+        gap = 10
+    elif gap > 40:
+        gap = 10
+
+    if amplitude < 0:
+        amplitude = 50
+    elif amplitude > 100:
+        amplitude = 50
+
     if fp:
-        command = shlex.split(
-            "espeak-ng -v{}+{} -p {} -s {} -g {} -a {} -w {} \"[[{}]]\""
-            .format(language, voice, pitch, speed, gap, amplitude, fp, text)
-        )
+        try:
+            fp = str(Path(fp).absolute())
+        except Exception as e:
+            print(e)
+            print("ERROR: 'fp' must be a valid path-like object or string.")
     else:
-        command = shlex.split(
-            "espeak-ng -v{}+{} -p {} -s {} -g {} -a {} \"[[{}]]\""
-            .format(language, voice, pitch, speed, gap, amplitude, text)
-        )
-        subprocess.run(command)
+        fp = ' '
+
+    command = shlex.split(
+        "espeak-ng -v{}+{} -p {} -s {} -g {} -a {} {} \"{}\""
+        .format(language, voice, pitch, speed, gap, amplitude, fp, text)
+    )
+
+    subprocess.run(command)
